This package installs the ERA5 interface for OMUSE.

In order to use the ERA5 interface, UID and API key from the CDS portal is 
needed (see the documentation for [CDSAPI](https://pypi.org/project/cdsapi/) 
for more details).
